Your message dated Sat, 10 Oct 2009 17:32:04 +0000
with message-id <[email protected]>
and subject line Bug#537467: fixed in ripit 3.8.0-1
has caused the Debian Bug report #537467,
regarding ripit -- several spelling errors
to be marked as done.

This means that you claim that the problem has been dealt with.
If this is not the case it is now your responsibility to reopen the
Bug report if necessary, and/or fix the problem forthwith.

(NB: If you are a system administrator and have no idea what this
message is talking about, this may indicate a serious mail system
misconfiguration somewhere. Please contact [email protected]
immediately.)


-- 
537467: http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=537467
Debian Bug Tracking System
Contact [email protected] with problems
--- Begin Message ---
Package: ripit
Version: 3.7.0-1
Severity: minor
Tags: patch

Hi!

I spent some time fixing all the spelling errors I could find in the
ripit source code as well as manual pages. Hope it is useful.

Thanks.

Kumar
-- 
Kumar Appaiah
--- ripit-3.7.0.orig/ripit.1
+++ ripit-3.7.0/ripit.1
@@ -1,4 +1,4 @@
-.TH RIPIT "1" "April 25th, 2009" "ripit" "RipIT audio convertor"
+.TH RIPIT "1" "April 25th, 2009" "ripit" "RipIT audio converter"
 .SH "NAME:"
 .PP
 ripit \- Perl script to create .flac .ogg .mp3 or .m4a (aac) files from
@@ -12,8 +12,8 @@
 audio CD. RipIT supports Flac, Lame, Oggenc and Faac. Artist and song
 titles are retrieved with the CDDB_get.pm and it is possible to submit
 and edit CDDB entries at freedb.org. Hidden tracks and ghost songs are
-detected and splitted into chunks of sound, a toc (cue) file permits to
-burn the wavs with text and no gaps in DAO mode. Several encoder formats
+detected and split into chunks of sound, a toc (cue) file permits to
+burn the WAV files with text and no gaps in DAO mode. Several encoder formats
 and qualities can be used at the same time and encoded into different
 directories.
 .SH "VERSION:"
@@ -31,7 +31,7 @@
 from track 5 to the last one. Default: not set.
 .TP
 \fB\-\-merge\fR ordered list of comma separated intervals
-Place a hyphen (-) or a plus (+) between first and last tracknumber to
+Place a hyphen (-) or a plus (+) between first and last track number to
 be merged. Separate several intervals with commas. Default: not set.
 .TP
 \fB\-o,\fR \fB\-\-outputdir\fR dir
@@ -42,7 +42,7 @@
 Path of audio CD device, default: /dev/cdrom.
 .TP
 \fB\-r,\fR \fB\-\-ripper\fR \fInumber\fP
-CDripper to use,
+CD ripper to use,
 .I 0
 \- dagrab,
 .I 1
@@ -80,7 +80,7 @@
 .TP
 \fB\-\-ghost\fR
 Analyze each wav for gaps and split it into chunks if gaps are detected
-and/or try to trim lead-in/out. This may overrided option merge. Delete
+and/or try to trim lead-in/out. This may override option merge. Delete
 blank tracks if only silence ("zero bytes") are found. Experimental!
 Default: off.
 .TP
@@ -164,7 +164,7 @@
 \fB\-B\fR option in Lame or the \fB\-M\fR option in Oggenc, default: 0.
 .TP
 \fB\-S,\fR \fB\-\-preset\fR \fImode\fP
-Use the preset switch when encoding with Lame. Combined with otpion
+Use the preset switch when encoding with Lame. Combined with option
 \fB\-\-vbrmode new\fR the preset fast will be used.
 Use \fB\-\-vbrmode old\fR not to use fast VBR. Mode is one of:
 .IR insane \ ( 320
@@ -243,14 +243,14 @@
 of remote machines where RipIT should encode. The output path must be
 the same for all machines. Specify the login (lo...@machine) only if not
 the same for the remote machine. Else just state the machine names. See
-EXAMPLES for more informtation, default: not set.
+EXAMPLES for more information, default: not set.
 .TP
 \fB\-\-scp\fR
-If the filesystem can not be accessed on the remote machines, scp (copy)
-the wavs to the remote machines, default: off.
+If the file system can not be accessed on the remote machines, scp (copy)
+the WAV files to the remote machines, default: off.
 .TP
 \fB\-\-local\fR
-Only used with option \fB\-\-sshlist\fR; if all encodings shall be
+Only used with option \fB\-\-sshlist\fR; if all encoding shall be
 done on remote machines, use \fB\-\-nolocal\fR, default: on.
 .TP
 \fB\-C,\fR \fB\-\-cddbserver\fR server
@@ -272,7 +272,7 @@
 .IR mirrors ,
 default: freedb. For more information check the webpage www.freedb.org.
 There is no list of mirrors available these days. This option might be
-obsolet as freedb uses random servers, but the default setting is
+obsolete as freedb uses random servers, but the default setting is
 mandatory.
 .TP
 \fB\-L,\fR \fB\-\-protocol\fR \fIlevel\fP
@@ -423,7 +423,7 @@
 will lead to severe compression of the audio signal, thus losing sound
 quality. Keeping the default value of -12dB is recommended.
 .br
-Default: -b Option v (q) will be set according to verbosity choosen.
+Default: -b Option v (q) will be set according to verbosity chosen.
 .TP
 \fB\-\-cdtoc\fR \fInumber\fP
 Number n =
@@ -442,13 +442,13 @@
 .IR 0 ),
 with minimal output (n =
 .IR 1 ),
-normal without encoder msgs (n =
+normal without encoder messages (n =
 .IR 2 ),
 normal (n =
 .IR 3 ),
 verbose (n =
 .IR 4 ),
-extremly verbose (n =
+extremely verbose (n =
 .IR 5 ).
 Default 3.
 .TP
@@ -483,7 +483,7 @@
 Change the directory permission to \fInumber\fP. Default: 0755.
 .TP
 \fB\-\-fpermission\fR \fInumber\fP
-Change the filepermission to \fInumber\fP. Default: 0644.
+Change the file permission to \fInumber\fP. Default: 0644.
 .TP
 \fB\-\-md5sum\fR
 Create a MD5-sum file for each type of sound files.
@@ -503,7 +503,7 @@
 .IP
 ripit \fB\-\-outputdir\fR /foo/paths/
 .PP
-To rip'n'code a special track selection, type
+To rip and encode a special track selection, type
 .IP
 ripit 1,3\-6,8\-11
 .PP

Attachment: signature.asc
Description: Digital signature


--- End Message ---
--- Begin Message ---
Source: ripit
Source-Version: 3.8.0-1

We believe that the bug you reported is fixed in the latest version of
ripit, which is due to be installed in the Debian FTP archive:

ripit_3.8.0-1.diff.gz
  to pool/main/r/ripit/ripit_3.8.0-1.diff.gz
ripit_3.8.0-1.dsc
  to pool/main/r/ripit/ripit_3.8.0-1.dsc
ripit_3.8.0-1_all.deb
  to pool/main/r/ripit/ripit_3.8.0-1_all.deb
ripit_3.8.0.orig.tar.gz
  to pool/main/r/ripit/ripit_3.8.0.orig.tar.gz



A summary of the changes between this version and the previous one is
attached.

Thank you for reporting the bug, which will now be closed.  If you
have further comments please address them to [email protected],
and the maintainer will reopen the bug report if appropriate.

Debian distribution maintenance software
pp.
Elimar Riesebieter <[email protected]> (supplier of updated ripit package)

(This message was generated automatically at their request; if you
believe that there is a problem with it please contact the archive
administrators by mailing [email protected])


-----BEGIN PGP SIGNED MESSAGE-----
Hash: SHA512

Format: 1.8
Date: Sat, 10 Oct 2009 16:38:38 +0200
Source: ripit
Binary: ripit
Architecture: source all
Version: 3.8.0-1
Distribution: unstable
Urgency: low
Maintainer: Elimar Riesebieter <[email protected]>
Changed-By: Elimar Riesebieter <[email protected]>
Description: 
 ripit      - Textbased audio cd ripper
Closes: 537467 548296 550491
Changes: 
 ripit (3.8.0-1) unstable; urgency=low
 .
   * New stable upstream release.
     - several spelling errors fixed (Closes: 537467)
     - determining the genre a wrong way fixed. (Closes: 548296)
   * debian/control: Changed Homepage: to the correct link (Closes: 550491)
   * Added libwebservice-musicbrainz-perl to Depends. MusicBrainz now supported
     with --mb commandline option.
   * Skipping manpage.patch: "escapes "-" to "\-" to be interpreted as minus by
     groff in ripit's manpage" Done upstream.
   * Introduced makefile.patch as we install ripit in ${DESTDIR}.
   * Bumped standard 3.8.3. No changes.
   * Added Readme.source
   * Removed Jesus Climent from Uploaders
Checksums-Sha1: 
 6e3611c9ed465e799f4dd48c098399406489393d 1694 ripit_3.8.0-1.dsc
 1b5a6c2cf64a9e6b9ec57e0c4505133e0b94afb3 115550 ripit_3.8.0.orig.tar.gz
 3b410a8cda78436139af8b1b50ba70836ca51f6e 4120 ripit_3.8.0-1.diff.gz
 906692abf242764cfffc9aa2801046cfeef85b70 113922 ripit_3.8.0-1_all.deb
Checksums-Sha256: 
 df1ea0795f8ada8a9aa577d57a825d63d41d6e515a1ae22253e6fe9c68ed9a50 1694 
ripit_3.8.0-1.dsc
 097169197b413656492f9b191555c090794bde028fccd532b3160910eec3b8a0 115550 
ripit_3.8.0.orig.tar.gz
 f325daaaa8121d55a0b8bbd3778c13b4ed8b5075f8e0559f8c36527f2b9582d5 4120 
ripit_3.8.0-1.diff.gz
 fcc48f9479254f1488b25e141c20370d33adb31104d32e7683cdb7be05a2e8ee 113922 
ripit_3.8.0-1_all.deb
Files: 
 ad371adc5136492ddda3b1af6a05b67d 1694 sound optional ripit_3.8.0-1.dsc
 ae7021700d93331aad13af5d18aa83de 115550 sound optional ripit_3.8.0.orig.tar.gz
 1aa1f850bd8b4e2b0edfffdde4b148e1 4120 sound optional ripit_3.8.0-1.diff.gz
 7cb79c0fdd737102b01fc852a5ab41c8 113922 sound optional ripit_3.8.0-1_all.deb

-----BEGIN PGP SIGNATURE-----
Version: GnuPG v1.4.10 (GNU/Linux)

iQIcBAEBCgAGBQJK0MOfAAoJEHqPSei2NIC+K/gQAJJls6vxcbEVquip03Ybmofo
zfVa5eZEcYtT9mScc1Wo2Y8xnZhAtp8hxZdmNFMcT64DAtZXOrUOHUnsjTqYIvO4
u9HpO6Ae7YrT2NXYbvE8o0QCZ2M700TbojOro3cWr7uoInsHYmANTljjq/21agGe
iNOmEjQtdKXjHvLnHCiUqGQLD9OZr5qvHzNWgGg0mCsJydaNHBO+HVi5dzvGvGUO
N7UUD2G7ulvDnZWCERLxpqV68bndD8q0KzMOhgHifz/WXsZdsxIi3tNYmdn2v2x3
OB+pNQHC5vuZfcgglRxuOljmG4FGp7lTVopuXsixPCFqSuWq84OUGBsa6qNX3qtK
PyHkv+NCzSLY9D+ws97ISwGJ5ia39lMlORN0wcviYxlJdBE2NvKTb8gxqUsltscI
zyzLRlIpJT5cwaO/dE4NSE3/Zskx/sbhH78lU3QgqO38wU2+KpM1jCZay8Q9oQS+
oVCOTJgo93H3nCvAau0RAhM0/SPbsRZL9N/2aAyYi/N9EQ8+05A2XGV4y3pivfzs
E9UfQXNzSTqPITySa8jM/2y3njyWRGZohWd57uRoY/Xsvb+Ik4Klh4Xbyx/7joKZ
De4yvR6uftq+e3OS2wQXVxTdah7lFfQbDZJmUbAs/BDmSCBs3j1GSZqTfmSZJao7
6t9e89LNWDo6Z2100Aup
=Po2A
-----END PGP SIGNATURE-----



--- End Message ---

Reply via email to
--- ripit-3.7.0.orig/ripit.pl
+++ ripit-3.7.0/ripit.pl
@@ -40,7 +40,7 @@
 #            8) Optional: saves the CDDB file
 #            9) Optional: creates a toc (cue) file to burn a CD in DAO
 #               with text
-#           10) Optional: anaylze the wavs for gaps and splits them into
+#           10) Optional: analyze the wavs for gaps and splits them into
 #               chunks and/or trim lead-in/out (experimental)
 #           11) Optional: merges wavs for gapless encoding
 #           12) Optional: creates a md5sum for each type of sound files.
@@ -92,7 +92,7 @@
                             # (0-8), lowest = 0, quality for Faac
                             # (10-500), best = 500
 my $qualame   = 5;          # Same as above, more intuitive. Use quotes
-my $qualoggenc= 3;          # if values shall be comma seperated lists.
+my $qualoggenc= 3;          # if values shall be comma separated lists.
 my $quaflac   = 5;          #
 my $quafaac   = 100;        #
 my $lameopt   = "";         #
@@ -103,7 +103,7 @@
 my $chars     = "XX";       # Exclude special chars in file names.
 my $verbose   = 3;          # Normal output: 3, no output: 0, minimal
                             # output: 1, normal without encoder msgs: 2,
-                            # normal: 3, verbose: 4, extremly verbose: 5
+                            # normal: 3, verbose: 4, extremely verbose: 5
 my $commentag = "";         # Comment ID3 tag.
 my $genre     = "";         # Genre of Audio CD for ID3 tag.
 my $year      = "";         # Year of Audio CD for ID3 tag.
@@ -120,7 +120,7 @@
                             # file (1 yes, 0 no).
 my $savepara  = 0;          # Save parameters passed in config file
                             # (1 yes, 0 no).
-my $config    = 1;          # Use config file to read paramaters
+my $config    = 1;          # Use config file to read parameters
                             # (1 yes, 0 no).
 my $submission= 1;          # Send CDDB submission
                             # (1 yes, 0 no).
@@ -166,13 +166,13 @@
                             # is ejected (option --eject)!
 my $ghost     = 0;          # Check and extract ghost songs from all
                             # tracks (1 yes, 0 no).
-my $prepend   = 2.0;        # Extend ghost songs by 2 sedonds at the
+my $prepend   = 2.0;        # Extend ghost songs by 2 seconds at the
                             # beginning.
-my $extend    = 2.0;        # Extend ghost songs by 2 sedonds at the
+my $extend    = 2.0;        # Extend ghost songs by 2 seconds at the
                             # end.
 my $dpermission = "0755";   # Directory permissions.
 my $fpermission = "";       # Audio and text file permissions.
-my $md5sum    = 0;          # Generate MD5 sums for evry sound file
+my $md5sum    = 0;          # Generate MD5 sums for every sound file
                             # not deleted (1 yes, 0 no).
 my @suffix    = ();         # Array of suffixes according to coders.
 my $multi     = 0;          # Not yet official. Do NOT use!
@@ -217,7 +217,7 @@
 #
 ########################################################################
 #
-# System variables, no user configurable varibales below.
+# System variables, no user configurable variables below.
 #
 use Encode;                 # Needed for decode_utf8 calls.
 use Fcntl;                  # Needed for sysopen calls.
@@ -233,7 +233,7 @@
 my $homedir = "$ENV{HOME}";
 my $workdir = "$ENV{PWD}";
 my $usename = "$ENV{USER}";
-# The hostname is not so important and not available on ubuntus (?).
+# The hostname is not so important and not available on Ubuntu (?).
 my $hostnam = "";
 if($ENV{HOSTNAME}) {
    $hostnam = "$ENV{HOSTNAME}";
@@ -435,7 +435,7 @@
 # save them in the config file) before config file is read to prevent
 # overriding passed options with options from config file. The passed
 # options shall be stronger than the config file options!
-# Problems arrise with options that can be zero. Because a usual if-test
+# Problems arise with options that can be zero. Because a usual if-test
 # can not distinguish between zero or undef, use the defined-test!
 #
 # First for the normal options, e. g. options which are never zero.
@@ -539,7 +539,7 @@
 }
 #
 print "\n\n\nRipIT version $version.\n" if($verbose >= 1);
-# Preliminary creaton of the infolog path.
+# Preliminary creation of the infolog path.
 # No log_system call here because this would try to write to the infolog
 # file not yet created.
 if($infolog) {
@@ -1156,8 +1156,8 @@
       $album = clean_all($cd{title});
       $artist = clean_all($cd{artist});
       # Remember: use of lowercase was supposed for file names only,
-      # tags should not be lowercased (what for?). But option
-      # ucfirst is usefull if DB entry is uppercase only, and tags
+      # tags should not be lowercase (what for?). But option
+      # ucfirst is useful if DB entry is uppercase only, and tags
       # in uppercase are rather ugly.
       $album = change_case($cd{title}) if($uppercasefirst == 1);
       $artist = change_case($cd{artist}) if($uppercasefirst == 1);
@@ -1203,7 +1203,7 @@
 
    # The strings from archive files should be OK, because the files
    # should be written in the corresponding encoding. Only strings
-   # from CDDB_get must be treaten.
+   # from CDDB_get must be treated.
    # But still, this gives the error:
    # Cannot decode string with wide characters at
    # /usr/lib/perl5/5.8.8/i586-linux-threads-multi/Encode.pm line 186.
@@ -1289,7 +1289,7 @@
       print "\nI don't know what to do. Is it cp-1252 or iso 8859-1?\n"
          if($verbose >= 5);
    }
-# Reseting the album and artist will srew up the track titles for the
+# Resetting the album and artist will screw up the track titles for the
 # Bang Bang case! Yes, change album and artist and tracknames will
 # blow up. That's life, that's Perl.
 #   # We use $cd{} for directory creation..., everything will be lost
@@ -1297,7 +1297,7 @@
 #   $cd{title} = $album;
 #   $cd{artist} = $artist;
 # Again: we need a save copy of the string as it is now! What is wrong
-# changeing an entry of a hash? Why are all other entries of that
+# changing an entry of a hash? Why are all other entries of that
 # hash screwed up?
 
    $album_utf8 = $album;
@@ -1382,12 +1382,12 @@
       # Note: seltrack is not yet defined... But we start to fill the
       # @secondlist array (yet empty) with track lengths in seconds.
       # TODO: push the pregap seconds to the list in any case, then we
-      # don't need to differentiate between the case hiddenfalg==1 or
+      # don't need to differentiate between the case hiddenflag==1 or
       # hiddenflag == 0 while choosing tracknames.
       push @secondlist, "$second" if($hiddenflag == 1);
    }
    my $n = 1;
-   # Print track infos.
+   # Print track information.
    foreach (@{$cd{track}}) {
       if($utf_latinflag >= $latinflag * 3 && $utf_wideflag == 0 && $wideflag == 0) {
          Encode::from_to($_, 'iso-8859-1', 'UTF-8');
@@ -1588,7 +1588,7 @@
       $album =~ s/ /_/g if($underscore == 1);
       $artist =~ s/ /_/g if($underscore == 1);
 
-      # Define variable for inital letter of artist.
+      # Define variable for initial letter of artist.
       my $iletter = $artist;
       $iletter =~ s/\s*(.).*/$1/;
       if($iletter =~ /\d/) {
@@ -1635,7 +1635,7 @@
       $dir =~ s,\s+/,/,g; # Do this in any case, even if all chars are
       $dir =~ s,\s+, ,g;  # allowed.
       $dir =~ s,\s-\s-\s*, ,g;
-      # Change case again only if lowercases wanted! Else we will get
+      # Change case again only if lowercase wanted! Else we will get
       # lower case of special dirtemplates like: $iletter/$artist: here
       # artist would be lowercased since we check for words!
       $dir = change_case($dir) if($lowercase == 1);
@@ -1646,7 +1646,7 @@
       $dir =~ s/^\///;
       my $soundir = $outputdir . "/" . $dir if($outputdir !~ /\/$/);
       $soundir = $outputdir . $dir if($outputdir =~ /\/$/);
-      # Check if the soundir alread exists, if it does, try "soundir i"
+      # Check if the soundir already exists, if it does, try "soundir i"
       # with i an integer until it works, unless option resume is given.
       my $cdexistflag = 0;
       my $i = 1;
@@ -1710,7 +1710,7 @@
       # -) internet
 
       # I tried this:
-      #umask(umask(0750) & ~0444); # Hm, the result is not as expecte.
+      #umask(umask(0750) & ~0444); # Hm, the result is not as expected.
 
       # Then I tired this:
       #umask($umask | 0666 ^ $dpermission) if(defined $dpermission);
@@ -1737,7 +1737,7 @@
       # the "user" bits are turned off, try something like:
       #umask((umask() & 077) | 7);
       # gives drwxr-x---, but that is not what the text says, right?
-      # No chance to understand umasks behaviour.
+      # No chance to understand umask behaviour.
 
       # Maybe this helps:   http://www.perlmonks.org/?node_id=543251
       # On the command line try this:
@@ -1755,8 +1755,8 @@
          # Explicitly log soundir creation.
          log_info("new-mediadir: $soundir");
 
-         # The so called Holzhacker-Method: creat dir level by level.
-         # Let me know the good way to do it, thanks.
+         # The so called Holzhacker-Method: create dir level by level.
+         # Let me know the best way to do it, thanks.
          my $growing_dir = "";
          foreach (split(/\//, $soundir)) {
             next if($_ eq " ");
@@ -1811,7 +1811,7 @@
       # all variables in are already lowercased!
       $tracktemplate =~ s/ /\\_/g if($underscore == 1);
       # We have to update tracknum and trackname because they
-      # are evalueted by the tracktemplate!
+      # are evaluated by the tracktemplate!
       my $tracknum = sprintf("%02d", $trnum);
       my $trackname = $trname;
       if(!eval("\$riptrname = $tracktemplate")) {
@@ -1916,7 +1916,7 @@
          $trackno = $trackcn . "-";
          shift(@skip);
          $trackcn++;
-         # Is the next tracknumber the last of the intervall of merged
+         # Is the next tracknumber the last of the interval of merged
          # tracks? If not, continue to increase the tracknumber.
          while($skip[0] && ($trackcn + 1) =~ /$skip[0]/) {
            $trackcn++;
@@ -2095,7 +2095,7 @@
       }
       # Check the hidden track for gaps. We do not care about option
       # merge... should we? Yes, we should. If option merge has been
-      # choosen for this track, splitting is not allowed, while
+      # chosen for this track, splitting is not allowed, while
       # extracting one chunk of sound may be desired.
       my @times = (0);
       if($ghost == 1 && $hiddenflag == 1) {
@@ -2214,7 +2214,7 @@
          if($normalize == 0) {
             # Start the encoder in the background, but only once.
             # We do it already here, because:
-            # i)  if all wavs are done, the encoding porcess at the end
+            # i)  if all wavs are done, the encoding process at the end
             #     of this subroutine will not be started at all!
             # ii) why should we wait for the first missing wav, if
             #     other wavs are already here and encoding could start
@@ -2257,7 +2257,7 @@
                last if($checknextflag == 2);
             }
          }
-         # Cdda2wav is somehow unpleasent. It dies not quick enough with
+         # Cdda2wav is somehow unpleasant. It dies not quick enough with
          # ^+c. I. e. even if a track has not been ripped to the end,
          # the *.rip file will become a *.wav. So we have to check for
          # completely encoded files and assume, that for not encoded
@@ -2363,7 +2363,7 @@
                \"$logfile.$riptrackno.txt\"";
             $ripcom = "nice -n $nicerip " . $ripcom if($nicerip != 0);
             unless(log_system("$ripcom")) {
-               # Apend error message to file srXY for rip2m to start
+               # Append error message to file srXY for rip2m to start
                # checktrack.
                open(SRXY,">>$logfile")
                   or print "Can not append to file \"$logfile\"!\n";
@@ -2440,7 +2440,7 @@
                2>> \"$logfile.$riptrackno.txt\"";
             $ripcom = "nice -n $nicerip " . $ripcom if($nicerip != 0);
             unless(log_system("$ripcom")) {
-               # Apend error message to file srXY for rip2m to start
+               # Append error message to file srXY for rip2m to start
                # checktrack.
                open(SRXY,">>$logfile")
                   or print "Can not append to file \"$logfile\"!\n";
@@ -2925,7 +2925,7 @@
             }
          }
       }
-      # This is an other hack to update the track-arrays modifed by the
+      # This is an other hack to update the track-arrays modified by the
       # ripper if ghost songs were found. Is there another way to
       # communicate with the parent process?
       # This loop was supposed to be at the end of this sub-routine,
@@ -3197,7 +3197,7 @@
          # $ghostflag to 2 after the last track has been done and
          # inserted in the playlist file as a regular file (below),
          # and insert sound files as ghost songs only when $ghostflag is
-         # 2. If only the last song has been splitted into chunks and
+         # 2. If only the last song has been split into chunks and
          # the counter increased, continue to insert as regular file.
          if($ghostflag == 2) {
             print PLST "GS$_:#EXTINF:$secondlist[$ghostcn - 1],",
@@ -3294,7 +3294,7 @@
       $_ =~ s/\.suffix$/.$suffix[$c]/i foreach (@mp3s);
       $_ =~ s/^Sepdir/$sepdir[$c]/ foreach (@mp3s);
       # Extension of playlist-file only needed when more than one
-      # encoder selected. Using seperate dirs, this would not be
+      # encoder selected. Using separate dirs, this would not be
       # necessary, but who says we use them? We keep the extension.
       if($#coder != 0) {
          $nplayfile = $playfile;
@@ -3352,7 +3352,7 @@
    $album = clean_all($album_utf8) if(defined $cd{title});
    $artist = clean_all($artist_utf8) if(defined $cd{artist});
 
-   # Preselect answer if no interaction whished.
+   # Preselect answer if no interaction requested.
    $index = 1 if($interaction == 0);
 
    while($index !~ /^[0-1]$/ ) {
@@ -3600,7 +3600,7 @@
       }
       $cddbsubmission = 1 unless($categ eq $cd{cat});
    }
-   # If one changes catecory for a new submission, set Revision to 0.
+   # If one changes category for a new submission, set Revision to 0.
    if($oldcat ne $categ && defined $cd{cat}) {
       $revision = 0;
    }
@@ -3970,12 +3970,12 @@
       # be "wrong", e.g. wave (instead of Darkwave or New Wave) or synth
       # instead of Synthpop, will be correct. Put the DB genre to ogenre
       # and get a new right-spelled genre... Note, we might get several
-      # possibilites, e.g. genre is Pop, then we get a bunch of
+      # possibilities, e.g. genre is Pop, then we get a bunch of
       # "pop-like" genres!
-      # There will be a linebreak, if multiple possibilities found.
+      # There will be a line break, if multiple possibilities found.
       my $ogenre = $genre;
       chomp($genre = `lame --genre-list 2>&1 | grep -i \'$genre\'`);
-      # Second we want THE original genre, if it precisly exists.
+      # Second we want THE original genre, if it precisely exists.
       chomp(my $testgenre = `lame --genre-list 2>&1 | grep -i \'\^... $ogenre\$\'`);
       $genre = $testgenre if($testgenre);
       # If we still have several genres:
@@ -4079,8 +4079,8 @@
 #
 sub check_quality {
    @pquality = defined unless(@pquality); # prevent warnings.
    # Remeber, if we come from reading the config file, the array
    # consists of a comma seperated string in the first entry only!
    if($pquality[0]) {
       @quality = split(/,/, join(',', @pquality));
    }
@@ -4115,7 +4115,7 @@
    # Actually check only those qualities needed, i.e. for choosen
    # encoders.
    # NOTE again: the $qualame etc. variables hold the string needed for
    # the config, it might be a comma seperated string. When passing
    # commands, we should not use them, but things like "$quality[$c]"
    # instead!
    my $corrflag = 0;
@@ -4351,7 +4351,7 @@
 
    # Create encoder array if passed or read from config file.
    # Remeber, if we come from reading the config file, the array
    # consists of a comma seperated string in the first entry only!
    if(@pcoder) {
       @coder = split(/,/, join(',', @pcoder));
    }
@@ -4514,7 +4514,7 @@
 
 # qualame: Sets audio quality for lame encoder in
 # cbr (lame-option -q) and vbr (lame-option -V) mode,
 # comma seperated list.
 # Possible values: 0...9, off
 # 0: higest quality
 # 9: lowest quality
@@ -4528,7 +4528,7 @@
 qualame=$qualame
 
 # lameopt: Additional options for lame encoder,
 # comma seperated list
 # Example: lameopt=-b 128,--preset extreme
 # Default: not set
 
@@ -4582,7 +4582,7 @@
 qualoggenc=$qualoggenc
 
 # oggencopt: Additional options for oggenc,
 # comma seperated list
 # Default: not set
 
 oggencopt=$oggencopt
@@ -4602,7 +4602,7 @@
 quaflac=$quaflac
 
 # flacopt: Additional options for flac encoder,
 # comma seperated list
 # Default: not set
 
 flacopt=$flacopt
@@ -4622,7 +4622,7 @@
 quafaac=$quafaac
 
 # faacopt: Additional options for faac encoder,
 # comma seperated list
 # Default: not set
 
 faacopt=$faacopt
@@ -5141,7 +5141,7 @@
       chomp($qualoggenc = $qualoggenc[0]) unless($pquality[0]);
       # I don't really like this. I don't like the variables qualame etc
       # too and wanted to get rid of them. Not possible anymore. We need
       # them because they hold a comma seperated string necessary to
       # write to the config file...
       unless($pquality[0]) {
          @qualame = split(/,/, $qualame);
@@ -6254,7 +6254,7 @@
               below. Default: 0.
  --faacopt Faac-options
               Pass other options to the encoder,  quote them with double
-              quotes if needed; comma seperated list if same enocder
+              quotes if needed; comma separated list if same enocder
               is used more than once. Default: not set.
  --flacopt Flac-options
               Same as above.
@@ -7299,7 +7299,7 @@
 #
 # Sort the options and fill the globopt array according to the encoder.
 # Remember, the list of options for one encoder stated several times is
 # seperated by commas. The *opt arrays below will have only one
 # entry, if the corresponding encoder has been stated only once. If one
 # needs to find globopt in the code, search for "$globopt[" and not for
 # @globopt.
@@ -7393,4 +7393,4 @@
 #
 sub check_distro {
    $distro = "debian" if(-f "/etc/debian_version");
-}
\ No newline at end of file
+}
@@ -4079,8 +4079,8 @@
 sub check_quality {
    @pquality = defined unless(@pquality); # prevent warnings.
-   # Remeber, if we come from reading the config file, the array
-   # consists of a comma seperated string in the first entry only!
+   # Remember, if we come from reading the config file, the array
+   # consists of a comma separated string in the first entry only!
    if($pquality[0]) {
       @quality = split(/,/, join(',', @pquality));
@@ -4115,7 +4115,7 @@
    # encoders.
    # NOTE again: the $qualame etc. variables hold the string needed for
-   # the config, it might be a comma seperated string. When passing
+   # the config, it might be a comma separated string. When passing
    # commands, we should not use them, but things like "$quality[$c]"
    # instead!
@@ -4351,7 +4351,7 @@
    # Create encoder array if passed or read from config file.
    # Remeber, if we come from reading the config file, the array
-   # consists of a comma seperated string in the first entry only!
+   # consists of a comma separated string in the first entry only!
    if(@pcoder) {
       @coder = split(/,/, join(',', @pcoder));
@@ -4514,7 +4514,7 @@
 # qualame: Sets audio quality for lame encoder in
 # cbr (lame-option -q) and vbr (lame-option -V) mode,
-# comma seperated list.
+# comma separated list.
 # Possible values: 0...9, off
 # 0: higest quality
@@ -4528,7 +4528,7 @@
 
 # lameopt: Additional options for lame encoder,
-# comma seperated list
+# comma separated list
 # Example: lameopt=-b 128,--preset extreme
 # Default: not set
@@ -4582,7 +4582,7 @@
 
 # oggencopt: Additional options for oggenc,
-# comma seperated list
+# comma separated list
 # Default: not set
 
@@ -4602,7 +4602,7 @@
 
 # flacopt: Additional options for flac encoder,
-# comma seperated list
+# comma separated list
 # Default: not set
 
@@ -4622,7 +4622,7 @@
 
 # faacopt: Additional options for faac encoder,
-# comma seperated list
+# comma separated list
 # Default: not set
 
@@ -5141,7 +5141,7 @@
       # I don't really like this. I don't like the variables qualame etc
       # too and wanted to get rid of them. Not possible anymore. We need
-      # them because they hold a comma seperated string necessary to
+      # them because they hold a comma separated string necessary to
       # write to the config file...
       unless($pquality[0]) {
@@ -7299,7 +7299,7 @@
 # Sort the options and fill the globopt array according to the encoder.
 # Remember, the list of options for one encoder stated several times is
-# seperated by commas. The *opt arrays below will have only one
+# separated by commas. The *opt arrays below will have only one
 # entry, if the corresponding encoder has been stated only once. If one
 # needs to find globopt in the code, search for "$globopt[" and not for
only in patch2:
unchanged: